@@ -19,11 +19,19 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ListDomainsPaginatorName", "SelectPaginatorName", "ServiceName", "PaginatorName")
+__all__ = (
+    "ListDomainsPaginatorName",
+    "SelectPaginatorName",
+    "SimpleDBServiceName",
+    "ServiceName",
+    "ResourceServiceName",
+    "PaginatorName",
+)
 
 
 ListDomainsPaginatorName = Literal["list_domains"]
 SelectPaginatorName = Literal["select"]
+SimpleDBServiceName = Literal["sdb"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -55,6 +63,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -177,6 +186,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -325,4 +335,16 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_domains", "select"]
