@@ -14,6 +14,8 @@ Usage::
 import sys
 from typing import Dict, List, Sequence
 
+from typing_extensions import NotRequired
+
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -45,26 +47,15 @@ __all__ = (
     "UpdateConditionTypeDef",
 )
 
-_RequiredAttributeTypeDef = TypedDict(
-    "_RequiredAttributeTypeDef",
+AttributeTypeDef = TypedDict(
+    "AttributeTypeDef",
     {
         "Name": str,
         "Value": str,
+        "AlternateNameEncoding": NotRequired[str],
+        "AlternateValueEncoding": NotRequired[str],
     },
 )
-_OptionalAttributeTypeDef = TypedDict(
-    "_OptionalAttributeTypeDef",
-    {
-        "AlternateNameEncoding": str,
-        "AlternateValueEncoding": str,
-    },
-    total=False,
-)
-
-
-class AttributeTypeDef(_RequiredAttributeTypeDef, _OptionalAttributeTypeDef):
-    pass
-
 
 BatchDeleteAttributesRequestRequestTypeDef = TypedDict(
     "BatchDeleteAttributesRequestRequestTypeDef",
@@ -89,47 +80,23 @@ CreateDomainRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredDeletableItemTypeDef = TypedDict(
-    "_RequiredDeletableItemTypeDef",
+DeletableItemTypeDef = TypedDict(
+    "DeletableItemTypeDef",
     {
         "Name": str,
+        "Attributes": NotRequired[Sequence["AttributeTypeDef"]],
     },
 )
-_OptionalDeletableItemTypeDef = TypedDict(
-    "_OptionalDeletableItemTypeDef",
-    {
-        "Attributes": Sequence["AttributeTypeDef"],
-    },
-    total=False,
-)
 
-
-class DeletableItemTypeDef(_RequiredDeletableItemTypeDef, _OptionalDeletableItemTypeDef):
-    pass
-
-
-_RequiredDeleteAttributesRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteAttributesRequestRequestTypeDef",
+DeleteAttributesRequestRequestTypeDef = TypedDict(
+    "DeleteAttributesRequestRequestTypeDef",
     {
         "DomainName": str,
         "ItemName": str,
+        "Attributes": NotRequired[Sequence["AttributeTypeDef"]],
+        "Expected": NotRequired["UpdateConditionTypeDef"],
     },
 )
-_OptionalDeleteAttributesRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteAttributesRequestRequestTypeDef",
-    {
-        "Attributes": Sequence["AttributeTypeDef"],
-        "Expected": "UpdateConditionTypeDef",
-    },
-    total=False,
-)
-
-
-class DeleteAttributesRequestRequestTypeDef(
-    _RequiredDeleteAttributesRequestRequestTypeDef, _OptionalDeleteAttributesRequestRequestTypeDef
-):
-    pass
-
 
 DeleteDomainRequestRequestTypeDef = TypedDict(
     "DeleteDomainRequestRequestTypeDef",
@@ -159,28 +126,15 @@ DomainMetadataResultTypeDef = TypedDict(
     },
 )
 
-_RequiredGetAttributesRequestRequestTypeDef = TypedDict(
-    "_RequiredGetAttributesRequestRequestTypeDef",
+GetAttributesRequestRequestTypeDef = TypedDict(
+    "GetAttributesRequestRequestTypeDef",
     {
         "DomainName": str,
         "ItemName": str,
+        "AttributeNames": NotRequired[Sequence[str]],
+        "ConsistentRead": NotRequired[bool],
     },
 )
-_OptionalGetAttributesRequestRequestTypeDef = TypedDict(
-    "_OptionalGetAttributesRequestRequestTypeDef",
-    {
-        "AttributeNames": Sequence[str],
-        "ConsistentRead": bool,
-    },
-    total=False,
-)
-
-
-class GetAttributesRequestRequestTypeDef(
-    _RequiredGetAttributesRequestRequestTypeDef, _OptionalGetAttributesRequestRequestTypeDef
-):
-    pass
-
 
 GetAttributesResultTypeDef = TypedDict(
     "GetAttributesResultTypeDef",
@@ -190,33 +144,21 @@ GetAttributesResultTypeDef = TypedDict(
     },
 )
 
-_RequiredItemTypeDef = TypedDict(
-    "_RequiredItemTypeDef",
+ItemTypeDef = TypedDict(
+    "ItemTypeDef",
     {
         "Name": str,
         "Attributes": List["AttributeTypeDef"],
+        "AlternateNameEncoding": NotRequired[str],
     },
 )
-_OptionalItemTypeDef = TypedDict(
-    "_OptionalItemTypeDef",
-    {
-        "AlternateNameEncoding": str,
-    },
-    total=False,
-)
-
-
-class ItemTypeDef(_RequiredItemTypeDef, _OptionalItemTypeDef):
-    pass
-
 
 ListDomainsRequestRequestTypeDef = TypedDict(
     "ListDomainsRequestRequestTypeDef",
     {
-        "MaxNumberOfDomains": int,
-        "NextToken": str,
+        "MaxNumberOfDomains": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListDomainsResultTypeDef = TypedDict(
@@ -231,57 +173,30 @@ ListDomainsResultTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredPutAttributesRequestRequestTypeDef = TypedDict(
-    "_RequiredPutAttributesRequestRequestTypeDef",
+PutAttributesRequestRequestTypeDef = TypedDict(
+    "PutAttributesRequestRequestTypeDef",
     {
         "DomainName": str,
         "ItemName": str,
         "Attributes": Sequence["ReplaceableAttributeTypeDef"],
+        "Expected": NotRequired["UpdateConditionTypeDef"],
     },
 )
-_OptionalPutAttributesRequestRequestTypeDef = TypedDict(
-    "_OptionalPutAttributesRequestRequestTypeDef",
-    {
-        "Expected": "UpdateConditionTypeDef",
-    },
-    total=False,
-)
 
-
-class PutAttributesRequestRequestTypeDef(
-    _RequiredPutAttributesRequestRequestTypeDef, _OptionalPutAttributesRequestRequestTypeDef
-):
-    pass
-
-
-_RequiredReplaceableAttributeTypeDef = TypedDict(
-    "_RequiredReplaceableAttributeTypeDef",
+ReplaceableAttributeTypeDef = TypedDict(
+    "ReplaceableAttributeTypeDef",
     {
         "Name": str,
         "Value": str,
+        "Replace": NotRequired[bool],
     },
 )
-_OptionalReplaceableAttributeTypeDef = TypedDict(
-    "_OptionalReplaceableAttributeTypeDef",
-    {
-        "Replace": bool,
-    },
-    total=False,
-)
-
-
-class ReplaceableAttributeTypeDef(
-    _RequiredReplaceableAttributeTypeDef, _OptionalReplaceableAttributeTypeDef
-):
-    pass
-
 
 ReplaceableItemTypeDef = TypedDict(
     "ReplaceableItemTypeDef",
@@ -302,27 +217,14 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredSelectRequestRequestTypeDef = TypedDict(
-    "_RequiredSelectRequestRequestTypeDef",
+SelectRequestRequestTypeDef = TypedDict(
+    "SelectRequestRequestTypeDef",
     {
         "SelectExpression": str,
+        "NextToken": NotRequired[str],
+        "ConsistentRead": NotRequired[bool],
     },
 )
-_OptionalSelectRequestRequestTypeDef = TypedDict(
-    "_OptionalSelectRequestRequestTypeDef",
-    {
-        "NextToken": str,
-        "ConsistentRead": bool,
-    },
-    total=False,
-)
-
-
-class SelectRequestRequestTypeDef(
-    _RequiredSelectRequestRequestTypeDef, _OptionalSelectRequestRequestTypeDef
-):
-    pass
-
 
 SelectResultTypeDef = TypedDict(
     "SelectResultTypeDef",
@@ -336,9 +238,8 @@ SelectResultTypeDef = TypedDict(
 UpdateConditionTypeDef = TypedDict(
     "UpdateConditionTypeDef",
     {
-        "Name": str,
-        "Value": str,
-        "Exists": bool,
+        "Name": NotRequired[str],
+        "Value": NotRequired[str],
+        "Exists": NotRequired[bool],
     },
-    total=False,
 )
